OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "اطلاعات CPU در دسترس نیست",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "RAM info not available" : "RAM info not available",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Copied!" : "رونوشت شد!",
    "Not supported!" : "پشتیبانی وجود ندارد!",
    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
    "System" : "سیستم",
    "Monitoring" : "نظارت بر",
    "Monitoring app with useful server information" : "برنامه نظارت با اطلاعات سرور مفید",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "اطلاعات سرور مفیدی مانند بار CPU ، استفاده از رم ، استفاده دیسک ، تعداد کاربران و غیره را ارائه می دهد.",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Unknown Processor",
    "Memory:" : "Memory:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "Load" : "بار",
    "Memory" : "حافظه",
    "Disk" : "دیسک",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Size:" : "اندازه",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "Files:" : "فایل ها:",
    "Storages:" : "انبارها:",
    "Free Space:" : "فضای خالی:",
    "Network" : "شبکه",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "کاربران فعال",
    "Last hour" : "Last hour",
    "Shares" : "اشتراک گذاری ها",
    "Users:" : "کاربران:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "PHP" : "PHP",
    "Version:" : "نسخه:",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "Upload max size:" : "اندازه حداکثر بارگذاری شود:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "Unable to list extensions",
    "Show phpinfo" : "Show phpinfo",
    "Database" : "پایگاه داده",
    "Type:" : "نوع:",
    "External monitoring tool" : "ابزار نظارت خارجی",
    "Copy" : "کپی کردن",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL."
},
"nplurals=2; plural=(n > 1);");
